Module patch_set

Module patch_set 

Utilities for parsing unified diff patches containing multiple files.

This module provides PatchSet for parsing patches that contain changes to multiple files, like the output of git diff or git format-patch.

Structs

FilePatch
A single file’s patch with operation metadata.
ParseOptions
Options for parsing patch content.
PatchSet
Streaming iterator for parsing patches one at a time.
PatchSetParseError
An error returned when parsing patches fails.

Enums

FileMode
File mode extracted from git extended headers.
FileOperation
The operation to perform based on a patch.
PatchKind
The kind of patch content in a FilePatch.