Utilities for parsing unified diff patches containing multiple files.
This module provides PatchSet for parsing patches that contain changes
to multiple files, like the output of git diff or git format-patch.
Structs
- File
Patch - A single file’s patch with operation metadata.
- Parse
Options - Options for parsing patch content.
- Patch
Set - Streaming iterator for parsing patches one at a time.
- Patch
SetParse Error - An error returned when parsing patches fails.
Enums
- File
Mode - File mode extracted from git extended headers.
- File
Operation - The operation to perform based on a patch.
- Patch
Kind - The kind of patch content in a
FilePatch.